# Generated by Django 4.0.1 on 2022-01-17 13:48

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Event',
            fields=[
                ('id', models.AutoField(primary_key=True, serialize=False)),
                ('initiator', models.CharField(max_length=250, verbose_name='Initiator')),
                ('timestamp', models.DateTimeField(auto_now_add=True, verbose_name='Date')),
                ('level', models.IntegerField(choices=[(0, 'NOTSET'), (20, 'INFO'), (30, 'WARNING'), (10, 'DEBUG'), (40, 'ERROR'), (50, 'CRITICAL')], default=0, verbose_name='Level')),
                ('event', models.TextField(default='', verbose_name='Event')),
                ('tracing', models.TextField(default='', verbose_name='Tracing')),
            ],
            options={
                'verbose_name': 'Event',
                'verbose_name_plural': 'Events',
                'db_table': 'eventlog',
                'ordering': ('-timestamp',),
            },
        ),
    ]
